/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -  This software is distributed in the hope that it will be
 -  useful, but with NO WARRANTY OF ANY KIND.
 -  No author or distributor accepts responsibility to anyone for the
 -  consequences of using this software, or for whether it serves any
 -  particular purpose or works at all, unless he or she says so in
 -  writing.  Everyone is granted permission to copy, modify and
 -  redistribute this source code, for commercial or non-commercial
 -  purposes, with the following restrictions: (1) the origin of this
 -  source code must not be misrepresented; (2) modified versions must
 -  be plainly marked as such; and (3) this notice may not be removed
 -  or altered from any source or modified source distribution.
 *====================================================================*/


#ifndef  COLORMAP_H_INCLUDED
#define  COLORMAP_H_INCLUDED



#define CM_BMP	   1      /* BMP colormap (array of RGBQUAD)            */
#define	CM_GIF     2      /* GIF colormap (array of GIFColorTableEntry) */


/*-----------------------------------------------------------------------*
 *                         Colormap structures                           *
 *-----------------------------------------------------------------------*/
/*
 *  Note: the colormap structure contains a ptr to the colormap table.
 *        We include data structures for building two different
 *        types of tables:
 *            - GIF three-byte array of GIFColorTableEntry structs
 *            - BMP four-byte array of RGBQUAD structs.
 *        The BMP format reserves an extra byte (e.g., for alpha channel).
 */
struct PixColormap
{
    INT32	 type;	    /* colormap table type {CM_BMP, CM_GIF}      */
    void	*array;	    /* colormap table                            */
    INT32	 size;	    /* number of bytes of colormap table         */
};
typedef struct PixColormap  PIXCMAP;



    /* GIF colormap table entry */
struct gifColorTableEntry
{
    UINT8       cmRed;
    UINT8       cmGreen;
    UINT8       cmBlue;
};
typedef struct gifColorTableEntry GIFColorTableEntry;



    /* BMP colormap table entry.
     * This is also the order (b,g,r) in which the color
     * samples are stored sequentially in the file */
struct tagRGBQUAD
{
    UINT8       rgbBlue;
    UINT8       rgbGreen;
    UINT8       rgbRed;
    UINT8       rgbReserved;
};
typedef struct tagRGBQUAD RGBQUAD;



#endif  /* COLORMAP_H_INCLUDED */


