/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -  This software is distributed in the hope that it will be
 -  useful, but with NO WARRANTY OF ANY KIND.
 -  No author or distributor accepts responsibility to anyone for the
 -  consequences of using this software, or for whether it serves any
 -  particular purpose or works at all, unless he or she says so in
 -  writing.  Everyone is granted permission to copy, modify and
 -  redistribute this source code, for commercial or non-commercial
 -  purposes, with the following restrictions: (1) the origin of this
 -  source code must not be misrepresented; (2) modified versions must
 -  be plainly marked as such; and (3) this notice may not be removed
 -  or altered from any source or modified source distribution.
 *====================================================================*/


#ifndef ENVIRON_H_INCLUDED
#define ENVIRON_H_INCLUDED


/*--------------------------------------------------------------------*
 *                          Built-in types                            *
 *--------------------------------------------------------------------*/
typedef signed char		INT8;
typedef unsigned char      	UINT8;
typedef short int		INT16;
typedef unsigned short int 	UINT16;
typedef long int		INT32;
typedef unsigned long int  	UINT32;
typedef float			FLOAT32;
typedef double			FLOAT64;


/*------------------------------------------------------------------------*
 *                            Standard macros                             *
 *------------------------------------------------------------------------*/
#ifndef MIN
#define MIN(x,y)      (((x) < (y)) ? (x) : (y))
#endif

#ifndef MAX
#define MAX(x,y)      (((x) > (y)) ? (x) : (y))
#endif

#ifndef ABS
#define ABS(x)        (((x) < 0) ? (-1 * (x)) : (x))
#endif

#ifndef SIGN
#define SIGN(x)       (((x) < 0) ? -1 : 1)
#endif

#ifndef UNDEF
#define UNDEF         -1
#endif

#ifndef NULL
#define NULL          0
#endif

#ifndef TRUE
#define TRUE          1
#endif

#ifndef FALSE
#define FALSE         0
#endif


/*--------------------------------------------------------------------*
 *         Use environ variables within compiler invocation           *
 *--------------------------------------------------------------------*/
/*
 *  To control conditional compilation, one of two variables is defined:
 *
 *       _LITTLE_ENDIAN_  (e.g., for Intel X86)
 *       _BIG_ENDIAN_     (e.g., for Sun SPARC)
 *
 *  The GCC compiler invocation sets these by defining either of:
 *
 *       X86_LINUX_ENV
 *       SPARC_ENV
 *
 *  N.B.  All code should compile properly for both hardware
 *        architectures.  However, it has only been thoroughly
 *        tested on X86 hardware.
 */
#ifdef X86_LINUX_ENV
#define _LITTLE_ENDIAN_
#endif

#ifdef SPARC_ENV
#define _BIG_ENDIAN_
#endif



/*------------------------------------------------------------------------*
 *                   Simple search state variables                        *
 *------------------------------------------------------------------------*/
#define   NOT_FOUND         0 
#define   FOUND             1 


/*------------------------------------------------------------------------*
 *                      Standard memory allocation                        *
 *------------------------------------------------------------------------*/
#define MALLOC(blocksize)           malloc(blocksize)
#define CALLOC(numelem, elemsize)   calloc(numelem, elemsize)
#define REALLOC(ptr, blocksize)     realloc(ptr, blocksize)
#define FREE(ptr)                   free(ptr)


/*------------------------------------------------------------------------*
 *              Control printing of error and warning messages            *
 *                                                                        *
 *      (Use -DNO_CONSOLE_IO on compiler line to prevent text output)     *
 *------------------------------------------------------------------------*/
extern char                         procName[];

#ifdef  NO_CONSOLE_IO

#define PROCNAME(name)
#define ERROR_PTR(a,b,c)            ((void *)(c))
#define ERROR_INT(a,b,c)            ((INT32)(c))
#define ERROR_FLOAT(a,b,c)          ((FLOAT32)(c))
#define ERROR_VOID(a,b)
#define WARNING(a,b)
#define WARNING_INT(a,b,c)

#else

#define PROCNAME(name)              static char procName[] = name
#define ERROR_PTR(a,b,c)            errorPtr((a),(b),(c))
#define ERROR_INT(a,b,c)            errorInt((a),(b),(c))
#define ERROR_FLOAT(a,b,c)          errorFloat((a),(b),(c))
#define ERROR_VOID(a,b)             errorVoid((a),(b))
#define WARNING(a,b)                warning((a),(b))
#define WARNING_INT(a,b,c)          warningInt((a),(b),(c))

#endif  /* NO_CONSOLE_IO */


#endif /* ENVIRON_H_INCLUDED */

