/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -  This software is distributed in the hope that it will be
 -  useful, but with NO WARRANTY OF ANY KIND.
 -  No author or distributor accepts responsibility to anyone for the
 -  consequences of using this software, or for whether it serves any
 -  particular purpose or works at all, unless he or she says so in
 -  writing.  Everyone is granted permission to copy, modify and
 -  redistribute this source code, for commercial or non-commercial
 -  purposes, with the following restrictions: (1) the origin of this
 -  source code must not be misrepresented; (2) modified versions must
 -  be plainly marked as such; and (3) this notice may not be removed
 -  or altered from any source or modified source distribution.
 *====================================================================*/

#ifndef  JBIG2_H
#define  JBIG2_H


/*
 * jbig2.h
 *
 *    The JB2DATA structure holds all the data required for
 *    the compressed jbig2 representation of an image.
 *    The data can be written to file, read back, and used
 *    to regenerate an approximate version of the original,
 *    which differs only in the use of a template image for a c.c.
 *    instead of the original instance, for each occurrence on the page.
 *
 */

struct Jbig2data
{
    struct Pix         *pix;        /* template composite for all classes    */
    INT32               w;          /* width of original image               */
    INT32               h;          /* height of original image              */
    INT32               nclass;     /* number of classes                     */
    INT32               latticew;   /* lattice width for template composite  */
    INT32               latticeh;   /* lattice height for template composite */
    struct Numa        *naclass;    /* array of class ids for each component */
    struct Pta         *pta;        /* array of UL corners at which the      */
                                    /* template is to be placed for each     */
				    /* component                             */
};
typedef struct Jbig2data    JB2DATA;



    /* These parameters are used for naming the two files
     * in which the jbig2 compressed data is stored.  */
#define   JBIG2_TEMPLATE_EXT      ".templates.png"
#define   JBIG2_DATA_EXT          ".data" 


#endif  /* JBIG2_H */


