/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -  This software is distributed in the hope that it will be
 -  useful, but with NO WARRANTY OF ANY KIND.
 -  No author or distributor accepts responsibility to anyone for the
 -  consequences of using this software, or for whether it serves any
 -  particular purpose or works at all, unless he or she says so in
 -  writing.  Everyone is granted permission to copy, modify and
 -  redistribute this source code, for commercial or non-commercial
 -  purposes, with the following restrictions: (1) the origin of this
 -  source code must not be misrepresented; (2) modified versions must
 -  be plainly marked as such; and (3) this notice may not be removed
 -  or altered from any source or modified source distribution.
 *====================================================================*/



#ifndef MORPH_H_INCLUDED
#define MORPH_H_INCLUDED

/* 
 *  morph.h
 */


/*
 *  used in structuring elements
 */
#define  DONT_CARE              0
#define  HIT                    1
#define  MISS                   2

/*
 *  used in granulometry
 */
#define  OFF                    0
#define  ON                     1

/*
 *  used by fast morphology and grayscale
 */
#define  HORIZ                  1
#define  VERT                   2
#define  DIAGONAL               3
#define  SQUARE                 4
#define  SEPARABLE              5

#define  DILATION               1
#define  EROSION                2
#define  OPENING                3
#define  CLOSING                4

#define  ADDED_BORDER           32    /* pixels, not bits */

/*
 *  used in rescaling grayscale images
 */
#define  LINEAR_SCALE           1
#define  LOG_SCALE              2

/*
 *  used in grayscale tophat
 */
#define  WHITE                  0
#define  BLACK                  1


/*
 *  used in grayscale arithmetic
 */
#define  ADD                    1
#define  SUBTRACT               2


/*-------------------------------------------------------------------------*
 *	                        Sel and Sel array                          *
 *-------------------------------------------------------------------------*/
struct Sel
{
    INT32         sy;          /* sel height                               */
    INT32         sx;          /* sel width                                */
    INT32         cy;          /* y location of sel origin                 */
    INT32         cx;          /* x location of sel origin                 */
    INT32       **data;        /* {0,1,2}; data[i][j] in [row][col] order  */
    char         *name;        /* used to find sel by name                 */
};
typedef struct Sel SEL;


struct Sela
{
    INT32            n;         /* number of sel actually stored           */
    INT32            nalloc;    /* size of allocated ptr array             */
    struct Sel     **sel;       /* sel ptr array                           */
};
typedef struct Sela SELA;



#endif  /* MORPH_H_INCLUDED */
