package ca.bcgsc.rwong.LRUI;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import javax.swing.filechooser.FileFilter;

import javax.swing.JFileChooser;
import javax.swing.JTextField;

/**
 * ActionListener for the brower buttons
 * opens up a file dialogue
 * depending on which browse button was pressed, 
 * open or save dialogue may be opened
 * a file filter may be set
 * @author rwong
 */
public class BrowseListener implements ActionListener {
	
	public static int SAVE = 0;
	public static int OPEN = 1;
	public static int FILTER_ALL_FILES = 0;
	public static int FILTER_IMAGES = 1;
	
	Component parent;
	int type;
	String desc;
	JTextField dest;
	int filter;
	
	/**
	 * creates a BrowseListener that is set up to call up a certain JFileChooser 
	 * @param parent the parent frame that the JFileChooser can tie to
	 * @param type can be OPEN or SAVE 
	 * @param desc text on the JFileChooser
	 * @param filter can be FILTER_ALL_FILES or FILTER_IMAGES
	 */
	public BrowseListener(Component parent, int type, String desc, JTextField dest, int filter){
		this.parent=parent;
		this.type = type;
		this.desc = desc;
		this.dest = dest;
		this.filter = filter;
	}

	/**
	 * called when the browse button is pressed
	 * will call up a JFileChooser of a preset type possibly with a filter
	 */
	public void actionPerformed(ActionEvent e) {
		final JFileChooser fc = new JFileChooser();
		fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
		fc.setMultiSelectionEnabled(false);
		fc.setDialogTitle(desc);
		
		if (filter == FILTER_IMAGES){
			fc.setAcceptAllFileFilterUsed(false);
			//set an file filter accepting only images
			fc.setFileFilter(new FileFilter(){
				public boolean accept(File pathname) {
					if (pathname.isDirectory()){
						return true;
					}
					String ext = null;
					String s = pathname.getName();
					int i = s.lastIndexOf('.');

					if (i > 0 &&  i < s.length() - 1) {
						ext = s.substring(i+1).toLowerCase();
					}
					if (ext != null){
						if (ext.equals("jpeg") ||
							ext.equals("jpg")||
							ext.equals("gif")||
							ext.equals("tiff")||
							ext.equals("tif")||
							ext.equals("png")){
							return true;
						}else{
							return false;
						}
					}else{
						return false;
					}
				}
				public String getDescription() {
					return "Images Only";
				}			
			});
		}else{
			//accept all files
			fc.setFileFilter(fc.getAcceptAllFileFilter());
		}
		if (type==OPEN){
			int returnVal = fc.showOpenDialog(parent);
			if (returnVal == JFileChooser.APPROVE_OPTION) {
				if(fc.getSelectedFile().isFile()){
					dest.setText(fc.getSelectedFile().getPath());
				}
			}
		}else if(type==SAVE){
			int returnVal = fc.showSaveDialog(parent);
			if (returnVal == JFileChooser.APPROVE_OPTION) {
	            dest.setText(fc.getSelectedFile().getPath());
			}
		}
	}

}
