package ca.bcgsc.rwong.LRUI;


import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import javax.swing.JButton;
import javax.swing.JOptionPane;

/**
 * Track if results have been changed and respond to save, reinit, revert and done 
 * buttons accordingly
 */
public class LanesManager implements ActionListener {
	
	/**
	 * this flag is set if user has signal to close the lanetracking window
	 */
	public static int CLOSING = 1;
	/**
	 * this flag is set if user has pressed the done button
	 */
	public static int DONE = 0;
	
	private String source;
	private String dest;
	private LaneRulerFrame parent;
	private boolean outEqualsIn=true;

	/**
	 * creates a lanes manager that holds location to destination and source lanes files
	 * @param lanesSource path to the source lanes file
	 * @param lanesDest path to the destination lanes file
	 * @param parentFrame handle to the lane tracking adjustment frame
	 */
	public LanesManager(String lanesSource, String lanesDest, LaneRulerFrame parentFrame){
		source = lanesSource;
		dest = lanesDest;
		parent = parentFrame;
	}
		
	public void actionPerformed(ActionEvent e) {
		JButton tempButton = (JButton) e.getSource();
		String buttonName = tempButton.getName();
		
		//write current node locations to file
		if (buttonName.equals("Save")){
			LanesWriter lw;
			try{
				if(parent.getGelPane().getAdjustPane().changed==true){
					lw = new LanesWriter(dest);
					lw.write(parent.getGelPane().getAdjustPane().nodeArray);
					lw.close();	
					parent.getGelPane().getAdjustPane().changed=false;
					outEqualsIn=parent.getGelPane().getAdjustPane().inLoaded;
				}
			}catch(IOException err){
				//already checked that lane dest is valid
			}		
		} else if (buttonName.equals("Revert")){ //revert to last save
			LanesReader lr;
			try{
				if(parent.getGelPane().getAdjustPane().changed==true){
					lr = new LanesReader(dest);
					parent.getGelPane().getAdjustPane().setNodes(lr.xVals, lr.yVals);
					parent.getGelPane().getAdjustPane().changed=false;
					if(outEqualsIn){
						parent.getGelPane().getAdjustPane().inLoaded=true;
					}
				}
			}catch(IOException err){
				//already checked that lane dest is valid
			}
		} else if (buttonName.equals("Reinit")){ //revert to source
			LanesReader lr;
			try{
				lr = new LanesReader(source);
				parent.getGelPane().getAdjustPane().setNodes(lr.xVals, lr.yVals);
				//last save different from input
				parent.getGelPane().getAdjustPane().changed=!outEqualsIn;
				parent.getGelPane().getAdjustPane().inLoaded = true;
			}catch(IOException err){
				//already checked that lane source is valid
			}
		} else if (buttonName.equals("Done")){
			checkSave(DONE);
		}
	}

	/**
	 * check if the result has changed since last save
	 * ask the user to save if true
	 * @param status can be DONE or EXIT, to prompt parent frame for appropriate action
	 */
	public void checkSave(int status){
		if (parent.getGelPane().getAdjustPane().changed){
			int result = JOptionPane.showOptionDialog(null, 
					"The lane positions has been modified since last save.\n" +
				    "would you like to save now?", 
				    "Warning: unsaved changes found", 
				    JOptionPane.YES_NO_CANCEL_OPTION, 
				    JOptionPane.WARNING_MESSAGE,
				    null,
				    null,
				    null);
			if(result == JOptionPane.YES_OPTION){
				LanesWriter lw;
				try{
					lw = new LanesWriter(dest);
					lw.write(parent.getGelPane().getAdjustPane().nodeArray);
					lw.close();	
				}catch(IOException err){
					//already checked that lane dest is vali
				}
			}
			
			if(result != JOptionPane.CANCEL_OPTION){
				parent.finish(status);
			}
		} else{
			parent.finish(status);
		}
	}
	
	
}
