package ca.bcgsc.rwong.LRUI;

import java.io.IOException;
import java.io.PrintWriter;

/**writes data to lanes file
 * 
 * @author rwong
 *
 */
public class LanesWriter {
	
	private PrintWriter writer;

	 /**
	  * create new writer to destination lane file
	  * @param outFileName path to the destination lanes file
	  * @throws IOException
	  */
	public LanesWriter(String outFileName) throws IOException{
		writer = new PrintWriter(outFileName);
	}

	/**
	 * extract all location information from a set of nodes 
	 * and write them to the file
	 * @param nodeData array of nodes representing all the nodes on a gel
	 */
	public void write(Node[][] nodeData){
		writer.printf("LANES\n");
		
		int zone;
		int row;
		 
		 for(zone=0; zone<nodeData.length;zone++)	 {
			 writer.printf("z=%d x=%.1f ", zone, nodeData[zone][0].getX());
			 for(row=0; row<nodeData[0].length;row++) {
				 writer.printf("%.1f ", nodeData[zone][row].getY());
			}
			 writer.printf("\n");
		 }
		writer.flush();
	}
	
	/**
	 * write to lanes file, given the node x position and y position separately
	 * @param xData x data for all nodes, same value for all nodes in a zone
	 * @param yData y data for all nodes, different for each node
	 */
	public void write(double[] xData, double[][] yData){
		writer.printf("LANES\n");
				
		int zone;
		int row;
		 
		 for(zone=0; zone<xData.length;zone++)	 {
			 writer.printf("z=%d x=%.1f ", zone, xData[zone]);
			 for(row=0; row<yData[0].length;row++) {
				 writer.printf("%.1f ", yData[zone][row]);
			}
			 writer.printf("\n");
		 }
		writer.flush();
	}
	
	/**
	 * close the writer
	 *
	 */
	public void close(){
		writer.close();
	}
	
}
