package ca.bcgsc.rwong.LRUI;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.JTextField;
import javax.swing.SpinnerNumberModel;
import javax.swing.SpringLayout;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.plaf.basic.BasicComboBoxRenderer;
import javax.swing.text.Document;

/**
 * Panel to take using input for gel settings
 * @author rwong
 *
 */
public class ParamPane extends JPanel implements DocumentListener, ChangeListener, ActionListener{

	private GelSettings param;
	
	private JTextField imSourceTF;
	private JTextField lSourceTF;
	private JTextField lDestTF;
	
	private static String Default_Image_Name = "image.tif";
	private static String Default_Lanes_Name = "lanes";
	
	/**
	 * starts a panel that takes in gel settings from the user
	 * @param gs struct where the gel settings will be saved
	 */
	public ParamPane(GelSettings gs){
	    
	    super(new SpringLayout());
		param=gs;
		
	    int numrows=0;
	    
	    JLabel imSource = new JLabel("Path to gel Image");
	    add(imSource);
	    imSourceTF = new JTextField(param.imageSource, 40);
	    imSource.setLabelFor(imSourceTF);
	    JPanel imSourceInputPanel = new JPanel(new SpringLayout());
	    imSourceInputPanel.add(imSourceTF);
	    JButton imSourceBrowse = new JButton("browse...");
	    imSourceBrowse.addActionListener(new BrowseListener(this, BrowseListener.OPEN, "choose gel image", imSourceTF, BrowseListener.FILTER_IMAGES));
	    imSourceInputPanel.add(imSourceBrowse);
	    SpringUtilities.makeCompactGrid(imSourceInputPanel,
	    		1, 2, //rows, cols
	            0, 0,        //initX, initY
	            6, 0);
	    
	    add(imSourceInputPanel);
	    
	    imSourceTF.getDocument().putProperty("name", "imSource");
	    imSourceTF.getDocument().addDocumentListener(this);
	    numrows++;
	    
	    JLabel lSource = new JLabel("Path to input lanes file");
	    add(lSource);
	    lSourceTF = new JTextField(param.lanesSource, 40);
	    lSource.setLabelFor(lSourceTF);
	    JPanel lSourceInputPanel = new JPanel(new SpringLayout());
	    lSourceInputPanel.add(lSourceTF);
	    JButton lSourceBrowse = new JButton("browse...");
	    lSourceBrowse.addActionListener(new BrowseListener(this, BrowseListener.OPEN, "choose input lanes file", lSourceTF, BrowseListener.FILTER_ALL_FILES));
	    lSourceInputPanel.add(lSourceBrowse);
	    
	    SpringUtilities.makeCompactGrid(lSourceInputPanel,
	    		1, 2, //rows, cols
	            0, 0,        //initX, initY
	            6, 0);
	    
	    add(lSourceInputPanel);
	    
	    lSourceTF.getDocument().putProperty("name", "lSource");
	    lSourceTF.getDocument().addDocumentListener(this);   

	    numrows++;
	    
	    JLabel lDest = new JLabel("Path to output lanes file");
	    add(lDest);
	    lDestTF = new JTextField(param.lanesDest, 40);
	    lDest.setLabelFor(lDestTF);
	    JPanel lDestInputPanel = new JPanel(new SpringLayout());
	    lDestInputPanel.add(lDestTF);
	    JButton lDestBrowse = new JButton("browse...");
	    lDestBrowse.addActionListener(new BrowseListener(this, BrowseListener.SAVE, "choose output lanes file destination", lDestTF, BrowseListener.FILTER_ALL_FILES));
	    lDestInputPanel.add(lDestBrowse);
	    
	    SpringUtilities.makeCompactGrid(lDestInputPanel,
	    		1, 2, //rows, cols
	            0, 0,        //initX, initY
	            6, 0);
	    
	    add(lDestInputPanel);

	    lDestTF.getDocument().putProperty("name", "lDest");
	    lDestTF.getDocument().addDocumentListener(this);   
	    
	    numrows++;
	    
	    JLabel nLanes = new JLabel("Number of Lanes");
	    add(nLanes);
	    JSpinner nLanesSP = new JSpinner(new SpinnerNumberModel(param.numLanes, 0, 500, 1)); 
	    nLanes.setLabelFor(nLanesSP);
	    add(nLanesSP); 
	    nLanesSP.addChangeListener(this);
	    nLanesSP.setName("nLanes");
	    numrows++;
	    
	    JLabel mOffset = new JLabel("Marker Offset");
	    add(mOffset);
	    JSpinner mOffsetSP = new JSpinner(new SpinnerNumberModel(param.markerOffset, 0, 500, 1));
	    mOffset.setLabelFor(mOffsetSP);
	    add(mOffsetSP); 
	    mOffsetSP.addChangeListener(this);
	    mOffsetSP.setName("mOffset");
	    numrows++;
	    
	    JLabel lastMOffset= new JLabel("Last Marker Offset");
	    add(lastMOffset);
	    JSpinner lastMOffsetSP = new JSpinner(new SpinnerNumberModel(param.lastMarkerOffset, 0, 500, 1));
	    lastMOffset.setLabelFor(lastMOffsetSP);
	    add(lastMOffsetSP); 
	    lastMOffsetSP.addChangeListener(this);
	    lastMOffsetSP.setName("lastMOffset");
	    numrows++;
	    
	    JLabel mPeriod= new JLabel("Marker Period");
	    add(mPeriod);
	    JSpinner mPeriodSP = new JSpinner(new SpinnerNumberModel(param.markerPeriod, 0, 500, 1));
	    mPeriod.setLabelFor(mPeriodSP);
	    add(mPeriodSP); 
	    mPeriodSP.addChangeListener(this);
	    mPeriodSP.setName("mPeriod");
	    numrows++;
	    
	    JLabel rotate = new JLabel("Gel edge with wells");
	    add(rotate);
	    String[] edgeStrings = {"Left", "Top", "Right", "Bottom"};
	    JComboBox rotateCP = new JComboBox(edgeStrings);  
	    rotate.setLabelFor(rotateCP);
	    rotateCP.setRenderer(new MyRenderer());
	    add(rotateCP);
	    rotateCP.addActionListener(this);
	    rotateCP.setName("rotate");
	    numrows++;
	    
	    JLabel xZoom = new JLabel("Initial X zoom factor");
	    add(xZoom);
	    JSpinner xZoomSP = new JSpinner(new SpinnerNumberModel(param.initXZoom, 0, 100, .2));
	    xZoom.setLabelFor(xZoomSP);
	    add(xZoomSP); 
	    xZoomSP.addChangeListener(this);
	    xZoomSP.setName("xZoom");
	    numrows++;
	    
	    JLabel yZoom = new JLabel("Initial Y zoom factor");
	    add(yZoom);
	    JSpinner yZoomSP = new JSpinner(new SpinnerNumberModel(param.initYZoom, 0, 100, .2));
	    yZoom.setLabelFor(yZoomSP);
	    add(yZoomSP); 
	    yZoomSP.addChangeListener(this);
	    yZoomSP.setName("yZoom");
	    numrows++;
	    
	    JLabel rSize = new JLabel("Size of node marker");
	    add(rSize);
	    JSpinner rSizeSP = new JSpinner(new SpinnerNumberModel(param.rectSize, 3, 100, 1));  
	    rSize.setLabelFor(rSizeSP);
	    add(rSizeSP); 
	    rSizeSP.addChangeListener(this);
	    rSizeSP.setName("rSize");
	    numrows++;
	    
	    JLabel sSize = new JLabel("Size of lane overlay");
	    add(sSize);
	    JSpinner sSizeSP = new JSpinner(new SpinnerNumberModel(param.strokeSize, 3, 100, 1));
	    sSize.setLabelFor(sSizeSP);
	    add(sSizeSP); 
	    sSizeSP.addChangeListener(this);
	    sSizeSP.setName("sSize");
	    numrows++;
	    	    
	    //Lay out the panel.
	    SpringUtilities.makeCompactGrid(this,
	    		numrows, 2, //rows, cols
	            6, 6,        //initX, initY
	            6, 6);       //xPad, yPad
	}
	
	
	public void changedUpdate(DocumentEvent e) {
		textUpdate(e);		
	}

	public void insertUpdate(DocumentEvent e) {
		textUpdate(e);	
	}

	public void removeUpdate(DocumentEvent e) {
		textUpdate(e);	
	}
	
	/**
	 * updates the file paths in gelsettings when the text field gets edited
	 * @param e
	 */
	public void textUpdate(DocumentEvent e) {
		Document temp = (Document) e.getDocument();

		try{
		if (temp.getProperty("name")=="imSource"){
			param.imageSource=temp.getText(0,temp.getLength());
			
			//set lanes file to same directory if nothing is set
			File lanesFile = new File(lSourceTF.getText());		
			if(lanesFile.getParent() == null){
				File imageFile = new File(temp.getText(0, temp.getLength()));
				if(imageFile.getParent() !=null){
					lSourceTF.setText(imageFile.getParent() + File.separator + Default_Lanes_Name);
				}		
			}
			return;
		}
		if (temp.getProperty("name")=="lSource"){
			param.lanesSource=temp.getText(0,temp.getLength());
			//set image file to same directory if nothing is set
			
			File imageFile = new File(imSourceTF.getText());		
			if(imageFile.getParent() == null){
				File lanesFile = new File(temp.getText(0, temp.getLength()));
				if(lanesFile.getParent() !=null){
					imSourceTF.setText(lanesFile.getParent() + File.separator + Default_Image_Name);
				}		
			}
			return;
		}
		if (temp.getProperty("name")=="lDest"){
			param.lanesDest=temp.getText(0,temp.getLength());
			return;
		}
		}catch(Exception err){
		}
	}

	/**
	 * handles events from the spinners 
	 */
	public void stateChanged(ChangeEvent e) {
		JSpinner temp = (JSpinner) e.getSource();
		if(temp.getName()=="nLanes"){
			param.numLanes=(Integer) temp.getValue();
			return;
		}
		if(temp.getName()=="mOffset"){
			param.markerOffset=(Integer) temp.getValue();
			return;
		}
		if(temp.getName()=="lastMOffset"){
			param.lastMarkerOffset=(Integer) temp.getValue();
			return;
		}
		if(temp.getName()=="mPeriod"){
			param.markerPeriod=(Integer) temp.getValue();
			return;
		}	
		if(temp.getName()=="xZoom"){
			param.initXZoom=(Double) temp.getValue();
			return;
		}
		if(temp.getName()=="yZoom"){
			param.initYZoom=(Double) temp.getValue();
			return;
		}
		if(temp.getName()=="rSize"){
			param.rectSize=(Integer) temp.getValue();
			return;
		}
		if(temp.getName()=="sSize"){
			param.strokeSize=(Integer) temp.getValue();
			return;
		}		
	}

/**
 * handles changes to the rotation combo box
 */
	public void actionPerformed(ActionEvent e) {
		JComboBox temp = (JComboBox) e.getSource();
		if(temp.getName()=="rotate"){
			String wellEdge = (String) temp.getSelectedItem();

			if(wellEdge == "Left"){
				param.rotateAngle=0;
			}else if(wellEdge == "Top"){
				param.rotateAngle=270;
			}else if(wellEdge == "Right"){
				param.rotateAngle=180;
			}else if(wellEdge == "Bottom"){
				param.rotateAngle=90;
			}
			return;
		}		
	}
}
class MyRenderer extends BasicComboBoxRenderer {
	public Component getListCellRendererComponent(
		JList list, Object value, int index, boolean isSelected, boolean cellHasFocus)
	{
		super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
 
		setHorizontalAlignment(JLabel.TRAILING);
 
		return this;
	}
}
