/**@file asymmetry.h
 *\brief header file for asymmetry.c, contains functions for calculating 
 *and evaluating the asymmetry in each lane*/

#ifndef ASYMMETRY_H
#define ASYMMETRY_H

#include "allheaders.h"
#include "gelinfo.h"
#include "anacutoff.h"
/**\brief factor to determine tolerance used when correcting a node*/
#define TOLERANCEFACTOR 3.0

/**\brief check symmetry of all the lanes, in groups of zones.  A corrected image of each lane is extracted using peak and node positions. */
int checkSymmetry(FILE *ERROROUT_FILE, FILE *FLAGOUT_FILE, PIX *pixGel, int* ZoneID, float **PeakPosition, float *NodePosition, struct GelInfo *GelInfo, struct AnaCutoff *AnaCutoff, float **Asym, float **Laneoffset, int *con_asym_lanes, int Verbose); 
/**\brief correct all peaks in predata identified to have low symmetry (noisy area) with filtered peak projection*/
int correctAsymmetry(INT32 **ZoneProjection, float **PeakPosition, float *Spacing, struct GelInfo *GelInfo, float **Asym, int MarkerInc); 
/** \brief based on Peak and Node Positions, the area of a given staighted lane is cropped out and returned*/
void followLane(PIX *pixGel, float **PeakPosition, float *NodePosition, struct GelInfo *GelInfo, int laneID, float **laneintensity);

/**\brief sorts an array of float*/
void shellSort(float numbers[], int array_size);

#endif
