/*defines struct to hold various gel parameters*/
#ifndef GELINFO_H
#define GELINFO_H 

/**\brief maximum length of file name*/
#define FILE_NAME_LEN 256

/**\brief holds various gel constants that is passed to different functions*/
struct GelInfo {
  /**\brief number of lanes (marker and data) in the gel*/
  int NumberOfLanes;
  /**\brief period at which the markers are placed, 1 more than the number of lanes between markers*/
  int MarkerPeriod;
  /**\brief lane number of the first marker lane*/
  int MarkerOffset; 
  /**\brief number of lanes the last marker is from the last lane*/
  int LastMarkerOffset;
  /**\brief number of markers in the gel*/
  int NumberOfMarkers;
  /**\brief number of zones used for analysis*/
  int NumberOfZones;
  /**\brief size of the structural element used for morphological closing operation*/
  int SizeOfStructuralElement;
  /**\brief width of the image, measured parallel to the lanes*/
  int ImageWidth;
  /**\brief height of the image, measured across the laens*/
  int ImageHeight;
  /**\brief ratio of gel spanned by the lanes*/
  float GelSpanFactor;
  /**\brief column identified as the start of the pre-data (region between wells and the first bands)*/
  int StartPreData;
  /**\brief column identified as the stop of the pre-data (region between wells and the first bands)*/
  int StopPreData;
  /**\brief column identified as the stop of the data*/
  int StopData;
  /**\brief the zone ID of the zone after the pre-data*/
  int FirstDataZone;
  /**\brief the row with the center of the bottommost lane*/
  int LowYBorder;
  /**\brief the row with the center of the topmost lane*/
  int HighYBorder;
  /**\brief the generic lane spacing of the entire gel*/
  float LaneSpacing;
  /**\brief the path to the project directory*/
  char ProjectDir[FILE_NAME_LEN];
  /*LIMS output*/
  /**\brief the largest number of consecutive of asymmetrical lanes*/
  int AsymSpan;
  /**\brief the number of markers with at least one low roughness section*/
  int NumLightMarker;
  /**\brief the size of the largest number of consecutive interpolated markers*/
  int NumInterpMarkerSpan;
  /**\brief a flag to denote if the gel has been successfully and confidently lanetracked*/
  int GelPassed;
  /**\brief the size of the largest number of consecutive noisy lanes*/
  int maxConsecNoise;
};

#endif
